@@ -3,4 +3,4 @@ from pytpp.attributes.agent_discovery_base import AgentDiscoveryBaseAttributes
 
 
 class AgentSSHDiscoveryAttributes(AgentDiscoveryBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Agent SSH Discovery"
