@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class AmazonAppAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Amazon App"
     access_key_id = Attribute('Access Key ID', min_version='16.1')
     aws_credential_dn = Attribute('Aws Credential DN', min_version='18.3')
     binding_target = Attribute('Binding Target', min_version='16.1')
