@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ApplicationGroupAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Application Group"
     certificate = Attribute('Certificate', min_version='19.4')
     common_data_location = Attribute('Common Data Location', min_version='19.4')
     common_data_vault_id = Attribute('Common Data Vault Id', min_version='19.4')
