@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class CiscoCSMAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "CiscoCSM"
     create_chain_trustpoints = Attribute('Create Chain Trustpoints')
     create_new_trustpoint = Attribute('Create New Trustpoint')
     enable_credential = Attribute('Enable Credential')
