@@ -3,7 +3,7 @@ from pytpp.attributes.client_work_base import ClientWorkBaseAttributes
 
 
 class ClientAgentSSHDiscoveryWorkAttributes(ClientWorkBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Client Agent SSH Discovery Work"
     clear_cache_timestamp = Attribute('Clear Cache Timestamp', min_version='20.1')
     days_of_month = Attribute('Days Of Month', min_version='15.1')
     days_of_week = Attribute('Days Of Week', min_version='15.1')
