@@ -3,7 +3,7 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class CloudInstanceMonitorDriverBaseAttributes(DriverBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Cloud Instance Monitor Driver Base"
     certificate_cleanup_options = Attribute('Certificate Cleanup Options', min_version='17.1')
     certificate_relocation_policy_dn = Attribute('Certificate Relocation Policy DN', min_version='17.1')
     cleanup_after = Attribute('Cleanup After', min_version='17.1')
