@@ -3,7 +3,7 @@ from pytpp.attributes.code_signing_environment_template_base import CodeSigningE
 
 
 class CodeSigningDotNetEnvironmentTemplateAttributes(CodeSigningEnvironmentTemplateBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Code Signing DotNet Environment Template"
     key_container_dn = Attribute('Key Container DN', min_version='20.2')
     key_storage_location = Attribute('Key Storage Location', min_version='20.2')
     max_uses = Attribute('Max Uses', min_version='20.2')
