@@ -4,7 +4,7 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class DiscoveryManagerAttributes(DiscoveryStatisticsAttributes, ServiceModuleAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Discovery Manager"
     connection_timeout = Attribute('Connection Timeout')
     delay = Attribute('Delay')
     load_percentage = Attribute('Load Percentage')
