@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_trust_store_base import CertificateTrustStoreB
 
 
 class F5LTMAdvancedTrustStoreAttributes(CertificateTrustStoreBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "F5 LTM Advanced Trust Store"
     certificate_name = Attribute('Certificate Name')
     ssh_port = Attribute('SSH Port')
     use_rest_api = Attribute('Use REST API', min_version='22.1')
