@@ -3,7 +3,7 @@ from pytpp.attributes.flow_action_base import FlowActionBaseAttributes
 
 
 class FlowEventActionAttributes(FlowActionBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Flow Event Action"
     condition = Attribute('Condition', min_version='19.2')
     data_content = Attribute('Data Content', min_version='19.2')
     event = Attribute('Event', min_version='19.2')
