@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class GeotrustEnterpriseCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Geotrust Enterprise CA"
     account_type = Attribute('Account Type')
     address = Attribute('Address')
     city = Attribute('City')
