@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class GroupAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Group"
     assets = Attribute('Assets', min_version='20.1')
     closed_group = Attribute('Closed Group', min_version='20.1')
     foreign_security_principal = Attribute('Foreign Security Principal', min_version='19.3')
