@@ -3,7 +3,7 @@ from pytpp.attributes.log_channel import LogChannelAttributes
 
 
 class LogSMTPAttributes(LogChannelAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Log SMTP"
     attachment_behavior = Attribute('Attachment Behavior', min_version='21.2')
     cc = Attribute('CC')
     host = Attribute('Host')
