@@ -4,7 +4,7 @@ from pytpp.attributes.proxy import ProxyAttributes
 
 
 class RedhatCAAttributes(HTTPCABaseAttributes, ProxyAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Redhat CA"
     agent_port = Attribute('Agent Port')
     agent_url_surffix = Attribute('Agent URL Surffix')
     end_entity_port = Attribute('End Entity Port')
