@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class ReportFilterBaseAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Report Filter Base"
     address = Attribute('Address')
     discoverydn = Attribute('DiscoveryDN')
     grouping = Attribute('Grouping')
