@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class StatisticsCounterAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Statistics Counter"
     sensitive = Attribute('Sensitive', min_version='19.3')
     statistic_id = Attribute('Statistic Id', min_version='19.3')
     tag_a_name = Attribute('Tag A Name', min_version='19.3')
