@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class ThawteSPKICAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Thawte SPKI CA"
     certificate_block = Attribute('Certificate Block')
     certificate_transparency = Attribute('Certificate Transparency', min_version='16.3')
     retrieval_period = Attribute('Retrieval Period', min_version='15.4')
