@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class VAMnShieldAttributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "VAM nShield"
     file_validation_disabled = Attribute('File Validation Disabled', min_version='15.3')
     install_path = Attribute('Install Path')
     km_local_path = Attribute('KM Local Path')
