@@ -4,7 +4,7 @@ from pytpp.attributes.proxy import ProxyAttributes
 
 
 class VerizonCAAttributes(HTTPCABaseAttributes, ProxyAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Verizon CA"
     admin_email = Attribute('Admin Email')
     admin_firstname = Attribute('Admin Firstname')
     admin_surname = Attribute('Admin Surname')
