@@ -3,7 +3,7 @@ from pytpp.attributes.validation_base import ValidationBaseAttributes
 
 
 class X509CertificateValidationAttributes(ValidationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "X509 Certificate Validation"
     detect_all_ssl_tls_protocols = Attribute('Detect All SSL TLS Protocols', min_version='15.3')
     network_validation_disabled = Attribute('Network Validation Disabled', min_version='15.3')
     use_common_name = Attribute('Use Common Name', min_version='15.3')
